<?php
// $Id: node_gallery.inc,v 1.1.2.2 2009/06/06 10:38:35 wilson98 Exp $

/**
 * @file
 * 
 * Node gallery models
 * 
 * gallery model: node, node->gallery_config, node->images, node->images_count(optional);
 * 
 * image model: node, node->image
 */

/**
 * Get node gallery config
 * 
 * the config was stored in variable table with this format: node_gallery_(gallery_type)-(image_type);
 *
 * @param unknown_type $gallery_type
 * @return unknown
 */
function node_gallery_get_config($gallery_type = NULL) {
  static $ng_configs = array();
  
  if (empty($ng_configs)) {
    global $conf;
    $node_types = array_keys(node_get_types());
    foreach ($conf as $key => $value) {
      if (strpos($key, 'node_gallery_') === 0 && !empty($value)) {
        $t = substr($key, 13);
        if (in_array($t, $node_types)) {
          $ng_configs[$t] = $value;
        }
      }
    }
  }
  if (!empty($gallery_type)) {
    return $ng_configs[$gallery_type];
  }
  return $ng_configs;
}

/**
 * get node gallery types list
 *
 * @param string $type: 'gallery' or 'image'
 * @return unknown
 */
function node_gallery_get_types($type = 'gallery') {
  static $ng_types = array();
  
  if (empty($ng_types)) {
    $ng_configs = node_gallery_get_config();
    foreach ($ng_configs as $key => $value) {
      $ng_types['gallery'][] = $key;
      $ng_types['image'][] = $value['image_type'];
    }
  }
  return $ng_types[$type];
}

function node_gallery_get_gallery_list($uid = NULL, $gallery_type = NULL) {
  $items = array();
  
  $gallery_types = empty($gallery_type) ? node_gallery_get_types() : array($gallery_type);
  $args = $gallery_types;
  $sql = "SELECT n.nid, n.title, n.type, n.created, n.uid FROM {node} n 
    WHERE n.type IN (". db_placeholders($gallery_types, 'varchar') .") AND n.status = 1";
  if ($uid) {
    $sql .= " AND n.uid = %d";
    $args[] = $uid;
  }
  $result = pager_query($sql, variable_get('node_gallery_page_number', 20), 0, NULL, $args);
  while ($object = db_fetch_object($result)) {
    $items[$object->nid] = $object;
  }
  if (!empty($items)) {
    $gids = array_keys($items);
    //we only need cover image when display gallery list;
    $result = db_query("SELECT ng.*, f.* FROM {node_galleries} ng INNER JOIN {files} f ON ng.fid = f.fid WHERE ng.gid IN (".
      db_placeholders($gids) .") AND ng.is_cover > 0", $gids);
    $i = 0;
    while ($object = db_fetch_object($result)) {
      if (!empty($object->nid) && !empty($object->gid)) {
        //we can't use $object->gid because it could be null;
        $items[$object->gid]->images[] = $object;
        $i++;
      }
    }
    //get the images count for display;
    $result = db_query("SELECT gid, COUNT(nid) AS count FROM {node_galleries} WHERE gid IN (". db_placeholders($gids) .") GROUP BY gid", $gids);
    while ($r = db_fetch_array($result)) {
      $items[$r['gid']]->images_count = $r['count'];
    }
  }

  return $items;
}

function node_gallery_get_gallery_images(&$node) {
  if (in_array($node->type, node_gallery_get_types())) {
    $sql = "SELECT n.nid, n.vid, n.title, n.type, n.created, nr.body, ng.*, f.* FROM {node} n 
      INNER JOIN {node_revisions} nr ON n.vid = nr.vid INNER JOIN {node_galleries} ng 
      ON n.nid = ng.nid INNER JOIN {files} f ON ng.fid = f.fid WHERE n.nid IN (SELECT g.nid FROM {node_galleries} g WHERE g.gid = %d) AND n.status = 1
       ORDER BY ng.weight, ng.nid";
    $result = db_query($sql, $node->nid);
    while ($object = db_fetch_object($result)) {
      $images[$object->nid] = $object;
    }
    //get the cck field content;
    if (module_exists('content') && !empty($images) && is_array($images)) {
      foreach ($images as &$item) {
        $content_type = content_types($item->type);
        if (!empty($content_type['fields'])) {
          content_load($item);
        }
      }
    }
    return $images;
  }
}

function node_gallery_get_cover($gallery) {
  if (!empty($gallery->images) && is_array($gallery->images)) {
    foreach ($gallery->images as $image) {
      if ($image->is_cover) {
        $cover_image = $image;
        break;
      }
    }
  }
  if (empty($cover_image)) {
    $cover_image->filepath = $gallery->gallery_config['default_cover'];
  }
  $cover_image->title = $gallery->title;
  return $cover_image;
}

function node_gallery_get_image_navigator($gid, $nid) {
  $result = db_query("SELECT nid FROM {node_galleries} WHERE gid = %d ORDER BY weight, nid", $gid);
  while ($r = db_fetch_array($result)) {
    $items[] = $r['nid'];
  }
  $navigator['total'] = count($items);
  $navigator['parent'] = $gid;
  for ($i = 0; $i < $navigator['total']; $i++) {
    if ($items[$i] == $nid) {
      $navigator['current'] = $i + 1;
      $navigator['prev_nid'] = ($i == 0) ? $items[$navigator['total'] - 1] : $items[$i - 1];
      $navigator['next_nid'] = ($i == ($navigator['total'] - 1)) ? $items[0] : $items[$i + 1];
    }
  }
  return $navigator;
}

function node_gallery_get_gallery_content($gid, $teaser = 0) {
  $node = db_fetch_object(db_query("SELECT teaser, body, format FROM {node_revisions} WHERE nid = %d", $gid));
  $node->body = isset($node->body) ? str_replace('<!--break-->', '', $node->body) : '';
  $node = node_prepare($node, $teaser);
  return $node->content['body']['#value'];
}

function node_gallery_delete_gallery($node) {
  return db_query("DELETE FROM {node_galleries} WHERE gid = %d", $node->nid);
}

function node_gallery_get_image_parent_gallery_config($image) {
  static $image_gallery_configs;
  
  //use the $image->nid as a token, because we don't know the image's parent gallery type.
  if (empty($image_gallery_configs[$image->nid])) {
    if (!empty($image->image->gid)) {
      $parent_type = db_result(db_query("SELECT n.type FROM {node} n INNER JOIN {node_galleries} ng ON n.nid = ng.gid
       WHERE ng.nid = %d", $image->nid));
       $image_gallery_configs[$image->nid] = node_gallery_get_config($parent_type);
    }
  }
  return $image_gallery_configs[$image->nid];
}

function node_gallery_get_image_file($node) {
  return db_fetch_object(db_query("SELECT i.*, f.* FROM {node_galleries} i INNER JOIN {files} f ON i.fid = f.fid WHERE i.nid = %d", $node->nid));
}

function node_gallery_image_save($form, $image_node) {
  module_load_include('inc', 'node', 'node.pages');
  $form_state['values'] = (array)$image_node;
  node_form_submit($form, $form_state);
  $image_node->nid = $image_node->image->nid = $form_state['nid'];
  
  file_set_status($image_node->image, FILE_STATUS_PERMANENT);
  if ($image_node->image->gid && $image_node->nid) {
    //update
    if (db_result(db_query("SELECT nid FROM {node_galleries} WHERE gid = %d AND nid = %d", $image_node->image->gid, $image_node->nid))) {
      return drupal_write_record('node_galleries', $image_node->image, array('gid', 'nid'));
    }
    //insert
    else {
      $has_images = db_result(db_query("SELECT nid FROM {node_galleries} WHERE gid = %d", $image_node->image->gid));
      //the first upload image is set to default cover;
      if (!$has_images) {
        $image_node->image->is_cover = 1;
      }
      else {
        //only one image can be set to cover;
        if ($image_node->image->is_cover) {
          db_query("UPDATE {node_galleries} SET is_cover = %d WHERE is_cover = 1 AND gid = %d", $image_node->image->gid);
        }
      }
      return drupal_write_record('node_galleries', $image_node->image);
    }
  }
}

function node_gallery_delete_image($node) {
  db_query("DELETE FROM {node_galleries} WHERE nid = %d", $node->nid);
  db_query("DELETE FROM {files} WHERE fid = %d", $node->image->fid);
  db_query("DELETE FROM {node} WHERE nid = %d", $node->nid);
  file_delete($node->image->filepath);
}