<?php
// $Id: node_gallery.themes.inc,v 1.17.4.2 2009/06/06 10:38:35 wilson98 Exp $

/**
 * @file
 * Node gallery themes. 
 *
 */

function theme_gallery_list($items, $account = NULL) {
  $output = '<div class="gallery-list">';
  $output .= node_gallery_operations('list', $account);
  if (empty($items)) {
    $output .= t('There are currently no galleries.');
  }
  else {
    $output .= theme('item_list', $items, NULL, 'ul', array('class' => 'gallery-cover-list'));
  }
  $output .= '</div>';
  
  return $output;
}

function template_preprocess_gallery_cover_view(&$vars) {
  $gallery = $vars['gallery'];
  $cover_image = node_gallery_get_cover($gallery);
  $vars['cover_image'] = theme('image_view', $gallery->gallery_config['image_size']['cover'], $cover_image);
  $vars['meta_data'] = theme('item_list', theme('gallery_meta', $gallery));
  $vars['cover_operations'] = node_gallery_operations('cover', $gallery);
}

function theme_gallery_meta($gallery) {
  $images_count = empty($gallery->images_count) ? count($gallery->images) : $gallery->images_count;
  $items[] = format_plural($images_count, '1 image', '@count images');
  $items[] = t('Created at: !date', array('!date' => format_date($gallery->created, 'custom', 'Y-m-d')));
  
  return $items;
}

function theme_gallery_image_view($type, $image, $config) {
  if ($type == 'cover') {
    if (empty($image)) {
      $image->filepath = $config['default_cover'];
    }
  }

  return theme('imagecache', $config['image_size'][$type], $image->filepath, $image->title, $image->title, array('class' => 'gallery-image-'. $type));
}

function theme_gallery_teaser($gallery, $config) {
  //cover display
  if ($config['teaser']['gallery_display_type'] == 'cover') {
    $cover = node_gallery_get_cover($gallery);
    $image_tag = theme('image_view', $config['image_size']['cover'], $cover);
    return l($image_tag, 'node/'. $gallery->nid, array('html' => TRUE));
  }
  // Lightbox2 gallery display
  elseif ($config['teaser']['gallery_display_type'] == 'lightbox2_gallery' &&  module_exists('lightbox2')) {
    // Note - There is no display num, as lightbox2 will require seeing all
    // thumbs
    // Make sure to avoid an "Invalid argument supplied for foreach()" error
    if ($gallery->images) {
      foreach ($gallery->images as $image) {
        $image_tag = theme('image_view', $config['image_size']['thumbnail'], $image);
        $items[] = l($image_tag, imagecache_create_url($config['teaser']['lightbox2_gallery'], $image->filepath), array('html' => TRUE, 'attributes' => array('rel' => 'lightshow['. $gallery->nid .']')));
      }
    }
    return theme('item_list', $items);
  }
  else { // return thumbnail display
    $display_num = $config['teaser']['thumbnails_num'];
    $i = 0;
    // Make sure to avoid an "Invalid argument supplied for foreach()" error
    if ($gallery->images) {
      foreach ($gallery->images as $image) {
        if ($i < $display_num) {
          $image_tag = theme('image_view', $config['image_size']['thumbnail'], $image);
          $items[] = l($image_tag, 'node/'. $gallery->nid, array('html' => TRUE));
        }
      }
    }
    return theme('item_list', $items);
  }
}

function theme_image_view($imagecache, $image) {
  return theme('imagecache', $imagecache, $image->filepath, $image->title, $image->title);
}

function theme_gallery_edit_images_form(&$form) {
  drupal_add_tabledrag('upload-attachments', 'order', 'sibling', 'upload-weight');
  
  $header = array('', t('Delete'), t('Thumbnail'), t('Edit'), t('Weight'), t('Cover'));
  foreach (element_children($form['files']) as $key) {
    // Add class to group weight fields for drag and drop.
    $form['files'][$key]['weight']['#attributes']['class'] = 'upload-weight';

    $row = array('');
    $row[] = drupal_render($form['files'][$key]['remove']);
    $row[] = theme('imagecache', $form['#config']['image_size']['thumbnail'], 
      $form['files'][$key]['filepath']['#value'], $form['files'][$key]['filename']['#value'], $form['files'][$key]['filename']['#value']);
    $row[] = drupal_render($form['files'][$key]['edit_form']);
    $row[] = drupal_render($form['files'][$key]['weight']);
    if ($form['is_cover']) {
      $row[] = drupal_render($form['is_cover'][$key]);
    }
    $rows[] = array('data' => $row, 'class' => 'draggable');
  }
  $output = theme('table', $header, $rows, array('id' => 'upload-attachments'));
  $output .= drupal_render($form);
  return $output;
}

function theme_gallery_images_list($gallery, $config) {
  $output = '<div class="gallery-images-list">';
  if (!count($gallery->images)) {
    $output .= '<p>'. t('There are no photos in this gallery currently.');
    if (node_gallery_user_access('edit', $gallery)) {
      $output .= '  '. l('Upload Some!', 'node/'. $gallery->nid .'/upload', array('query' => 'destination=node/'. $gallery->nid));
    }
    $output .= '</p>';
  }
  /*elseif ($config['gallery']['gallery_display_type'] == 'lightbox2_gallery' && module_exists('lightbox2')) {
    foreach ($gallery->images as $nid => $image) {
      $items[] = theme('gallery_image_lightbox2', $image, $config, $gallery);
    }
    $output .= theme('item_list', $items);    
  }
  else {
    foreach ($gallery->images as $nid => $image) {
      $items[] = theme('gallery_image_thumbnail', $image, $config);
    }
    $output .= theme('item_list', $items); 
  }*/
  else {
    foreach ($gallery->images as $nid => $image) {
      $items[] = theme('gallery_list_image', $image, $config);
    }
    $output .= theme('item_list', $items);
  }
  $output .= "<div class='clearfix'></div>";
  $output .= '</div>';

  return $output;
}

function theme_gallery_list_image($image, $config) {
  if ($config['gallery']['gallery_display_type'] == 'lightbox2_gallery' && module_exists('lightbox2')) {
    return theme('gallery_image_lightbox2', $image, $config);
  }
  else {
    return theme('gallery_image_thumbnail', $image, $config);
  }
}

function theme_gallery_image_thumbnail($image, $config) {
  $output = '<div class="image-thumbnail">';
  $output .= l(theme('image_view', $config['image_size']['thumbnail'], $image), 'node/'. $image->nid, array('html' => TRUE));
  $output .= l($image->title, 'node/'. $image->nid);
  $output .= '</div>';
  return $output;
}

function theme_gallery_image_lightbox2($image, $config) {
  $output = '<div class="image-thumbnail">';
  $output .= l(theme('image_view', $config['image_size']['thumbnail'], $image), imagecache_create_url($config['gallery']['lightbox2_gallery_preset'], $image->filepath), array('html' => TRUE, 'attributes' => array('rel' => 'lightshow[hi]')));
  $output .= l($image->title, 'node/'. $image->nid);
  $output .= '</div>';
  return $output;
}

function theme_gallery_image_navigator($navigator, $image) {
  $col1 = array('data' => t("Image %current/Total %total", array('%current' => $navigator['current'], '%total' => $navigator['total'])),
    'class' => 'image-navigator-left');
  $col2 = array('data' => l(t('Prev'), 'node/'. $navigator['prev_nid']) .'/'. l(t('Next'), 'node/'. $navigator['next_nid']),
    'class' => 'image-navigator-mid');
  $col3 = array('data' => node_gallery_operations('image', $image), 'class' => 'image-navigator-right');
  $rows[] = array($col1, $col2, $col3);

  return theme('table', NULL, $rows, array('class' => 'image-navigator')); 
}